@@ -1,5 +1,5 @@
 
-"""Jaime Sendra Berenguer-2018-2022.
+"""Jaime Sendra Berenguer-2020.
 MLearner Machine Learning Library Extensions
 Author:Jaime Sendra Berenguer<www.linkedin.com/in/jaisenbe>
 License: MIT
@@ -40,7 +40,7 @@ logger.setLevel(logging.INFO)
 # Dev branch marker is: 'X.Y.dev' or 'X.Y.devN' where N is an integer.
 # 'X.Y.dev0' is the canonical version of 'X.Y.dev'
 #
-__version__ = '0.1.8'
+__version__ = '0.2.1'
 
 
 # On OSX, we can get a runtime error due to multiple OpenMP libraries loaded
