@@ -1,11 +1,12 @@
 """
-Jaime Sendra Berenguer-2018-2022.
+Jaime Sendra Berenguer-2020.
 MLearner Machine Learning Library Extensions
 Author:Jaime Sendra Berenguer<www.linkedin.com/in/jaisenbe>
 License: MIT
 """
 
 from .params_manager import ParamsManager
+from .keras import keras_checkpoint
 
 
-__all__ = ["ParamsManager"]
+__all__ = ["ParamsManager", "keras_checkpoint"]
